#
# spec file for package media-player-info
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d
Name:           media-player-info
Version:        26
Release:        1.1
Summary:        Media Player Information
# Note on license: some files in the tools subdirectories are GPL-2.0+ (or
# MIT); those files are not shipped at all in the resulting binary package.
# Hence, the binary package is indeed still BSD-3-Clause.
License:        BSD-3-Clause
Group:          System/GUI/Other
URL:            https://www.freedesktop.org/wiki/Software/media-player-info/
Source:         %{name}-%{version}.tar.zst
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
BuildArch:      noarch

%description
This package contains a repository of data files describing media player
(mostly USB Mass Storage ones) capabilities. These files contain information
about the directory layout to use to add music to these devices, about the
supported file formats, ... These capabilities used to be provided by HAL
in the 10-usb-music-players.fdi file but had to be moved elsewhere as part
of the big HALectomy.

%prep
%autosetup

%build
NOCONFIGURE=1 ./autogen.sh
%configure
%make_build

%install
%make_install

%post
%{udev_hwdb_update}
%udev_rules_update

%postun
if [ $1 -eq 0 ]; then
        %{udev_hwdb_update}
        %udev_rules_update
fi

%files
%license COPYING
%doc AUTHORS NEWS
%dir %{_datadir}/media-player-info
%{_datadir}/media-player-info/*.mpi
%{_udevhwdbdir}/20-usb-media-players.hwdb
%{_udevrulesdir}/40-usb-media-players.rules
%{_datadir}/metainfo/org.freedesktop.media_player_info.metainfo.xml

%changelog
* Thu Dec 19 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 26:
  + Fix and validate generated AppStream metainfo file
- Changes from version 25:
  + Generate AppStream metainfo file
  + Fix incorrect USB DeviceMatch=
- Switch to source service git checkout. Following this, add
  libtool BuildRequires, and bootstrap build.
* Tue Jun 16 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 24:
  * Move to new freedesktop GitLab repository, update README.md
    accordingly
  * Drop non-hwdb mode, require udev 196 now
  * Several build system cleanups and robustifications
- Drop reproducible.patch
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Fri May  3 2019 vuntz@opensuse.org
- Update to version 23:
  + mpi2hwdb.py: Export the icon through hwdb to udev
  + mpi2hwdb.py: Force default icon to be multimedia-player
  + Sort list of mpi files to get reproducible rules/hwdb
* Tue May  2 2017 bwiedemann@suse.com
- Add reproducible.patch to make build fully reproducible
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 22:
  + Terminate udev rules with an empty line (lp#1364747).
  + Add Sandisk Sansa Clip Sport (lp#1296418).
  + Remove ZTE Score (deb#748647).
- Drop fix-udev-rules-creator.patch: Fixed upstream.
* Sun Apr 27 2014 coolo@suse.com
- buildrequire systemd to avoid a conflict with systemd-mini
  (actually a short coming the way post requires are added
  to the buildenv without checking for conflicts with previous
  build requires)
* Mon Sep 30 2013 fcrozat@suse.com
- Add fix-udev-rules-creator.patch: fix missing eol causing udev
  warning (git).
- Ensure udev is notified when package is installed / updated /
  uninstalled.
* Fri Jul 26 2013 hrvoje.senjan@gmail.com
- Update to version 21:
  + Fix build under non-UTF8 locales
- Changes from version 20:
  + Fix build in separate build tree
- Changes from version 19:
  + Drop obsolete fdi2mpi.py
  + Port generator tools to Python 3
  + Rename mpi files with overly long names
  + Add Motorola Droid 4
  + Create udev hwdb when building with udev >= 196
- Changes from version 18:
  + Add HP Veer
  + Add Archos 5 Internet Tablet
  + Add ZTE Score
  + Add LG Optimus One P500
  + Drop newer kindles
  + Fix playlist path for Sony Ericsson Xperia mini pro
- Added python3 BuildRequires for new generator tools
* Sun Oct 21 2012 fcrozat@suse.com
- Fix build with older openSUSE releases.
* Sat Oct 13 2012 coolo@suse.com
- move udev rules to /usr
* Sun Sep 16 2012 zaitor@opensuse.org
- Update to version 17:
  + Add support for Creative Zen MX, Nec LifeTouch Note,
    Nokia C7-00, Sony Ericsson Xperia Mini, iBeat Jess, Nokia N9.
  + Xperia X12 is better known as Xperia arc.
  + Galaxy Gio (GT-S5660) shares same ID as Ace.
  + Add a third ID for Acer Liquid (MT).
  + Add playlist format to Android devices.
  + Add alternative product ID for Sony Ericsson Xperia X10.
* Sun Jul 22 2012 coolo@suse.com
- change buildrequires of udev to expect the pkg-config file
* Tue Feb 14 2012 vuntz@opensuse.org
- Add comments to clarify the license of the package (bnc#743602):
  while some files in the tarball are GPL-2.0+ or MIT, those are
  not shipped in any form in the resulting binary package.
* Tue Jan 24 2012 vuntz@opensuse.org
- Update to version 16:
  + Add support for Archos Key, Nokia N950, Sandisk Sansa Clip ZIP,
    Sony Walkman NWZ-A800 series, Sony Walkman NWZ-S545,
    Sony Walkman NWZ-S76x, Sony Walkman S-750 series.
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Wed Oct  5 2011 vuntz@opensuse.org
- Update to version 15:
  + Add playlist path to all Android devices.
  + Remove %%File references from PlaylistPath property.
  + Define "FolderSeparator" and "LineEnding" properties.
  + Add support for Acer Liquid, Archos A43 Internet Tablet,
    Barnes and Noble Nook eReaders, Cowon iAUDIO E2,
    Creative Zen Style 300, Galaxy S 2, GoGear Vibe 4Gb, HP Pre 3,
    HP Touchpad, LG Optimus S, MicroMax A60, Motorola Atrix,
    Nokia 6730 Classic, Notion Ink Adam Tablet, Palm Pre 2,
    Philips GoGear Raga, Samsung Galaxy Ace, Samsung Freeform II,
    Samsung Galaxy S2, Samsung Galaxy SII, Samsung Reality,
    Sharp IS03, Sony Ericsson Vivaz, Sony Ericsson W705,
    Sony Ericsson Xperia mini pro, Sony Ericsson Xperia Play,
    Sony Ericsson Xperia X12 (Arc), TrekStor i.Beat rock,
    Vodafone 845 (Huawei U8120).
  + Improve support for Sandisk Sansa Clip+, Sandisk Sansa Fuze,
    Sony Walkman NWZ-S638F
* Mon May  2 2011 vuntz@opensuse.org
- Update to version 14:
  + Add support for Creative Zen X-Fi, Pantech SIRIUS alpha,
    Sandisk Sansa Fuze+, Sharp IS01, Sony Ericsson C905.
  + Improve support for Creative Zen X-Fi Style, HTC Legend.
- Changes from version 13:
  + Do not generate icon rules as it is currently broken
    (lp#657609)
  + Add suppor tfor Coby players, Huawei Ideos, Motorola Droid 2,
    RCA H100a, Samsung U6, Sony Ericsson XPERIA X1, Sony Walkman
    NWZ-E355.
  + Improve suppor for Creative Zen Stone, HTC Desire, HTC Evo, LG
    0x6018, Samsung Galaxy S, Sony Ericsson K800i, Sony Ericsson
    Xperia X10 mini Pro.
* Sun Jan  9 2011 vuntz@opensuse.org
- Update to version 12:
  + Add support for more Blackberries, Cowon J3, Google Nexus S,
    HTC EVO 4G, more Kindles, LG Ally, LG Optimus One, LG Vortex,
    Nokia 6700, Philips GoGear Aria, Philips GoGear RaGa, Samsung
    GT-S8000 Jet, Samsung YP-P2, Sony Ericsson Xperia X8.
  + Improve suppport for Blackberries, iPods, iRiver T30, Philips
    GoGear Opus, Samsung Galaxy.
* Wed Dec  8 2010 vuntz@opensuse.org
- Update to version 11:
  + Add support for many devices from Acer, Ali, Archos, Cowon,
    Creative, Dane-Elec, HTC, Huawei, iRiver, LG, Motorola, Nokia,
    Philips, Samsung, Sandisk, Sansa, Sony Ericsson, Sony.
  + Improve support for various devices.
* Sat Oct  9 2010 vuntz@opensuse.org
- Update to version 10:
  + mpi2udev.py: Add missing comma in rules with icons
  + Add automatic syntax checking
  + Sanitize name of iRiver T30 and of hama T30
  + Add devices:
  - Archos Vision 18
- Changes from version 9:
  + Fix Apple video player detection
  + Mark android devices as such
  + Mark the n900 as a maemo device
  + Mark the Palm Pre as a WebOS device
  + Give user-readable name to HTC Diamond mpi file
  + Fix Xperia X10 device ID
  + Add devices:
  - another HTC Diamond ID
  - another Samsung Galaxy ID
  - another Motorola Droid
  - Xperia X10 usb ID
  - Motorola CLIQ
  - Sony Xperia X10 Mini
  - Samsung YP-M1
  - Motorola Dext
  - iRiver E30
- Changes from version 8:
  + Fix OutputFormats syntax
  + Add audio/flac as output format for the Samsung Galaxy
- Changes from version 7:
  + Add parser tools to the distribution
  + Dual-license fdi2mpi.py under X11, too
  + Rebuild udev rules on changes of mpi2udev.py
  + mpi2udev.py: Add matching to USB product and manufacturer name
  + README: Improve description of detection
  + Add devices:
  - Sony Ericsson Xperia X10
  - another Samsung Galaxy ID
  - Rockbox players
  - Archos 5 IMT
  - TEAC MP3 Player MP-375SD
* Thu Apr  8 2010 vuntz@opensuse.org
- Update to version 6:
  + Add icon for HTC G1 phone
  + Add Palm Prē
  + Add Samsung Galaxy
  + Add Nokia N900 phone
  + Add MP3 support to the Samsung Galaxy
  + Add Google Nexus One
  + Add Huawei Pulse phone
  + Add icon for Google Nexus One phone
  + Fix name of iPod icon name
  + Fix format of DeviceMatch entries in new mpi files
  + Add mpi file for Sansa Clip+
  + Fix udev rules to catch MTP devices, too
  + Add Cowon S9
* Tue Mar 23 2010 vuntz@opensuse.org
- New package: media-player-information is needed in a hal-free
  world to get information about media player. This is a
  freedesktop.org initiative.
